@@ -1,5 +1,5 @@
 #!/bin/bash
-# Copyright 1999-2018 Gentoo Foundation
+# Copyright 1999-2021 Gentoo Authors
 # Distributed under the terms of the GNU General Public License v2
 
 # Prevent aliases from causing portage to act inappropriately.
@@ -23,6 +23,8 @@ __check_bash_version() {
 		maj=3 min=2
 	elif ___eapi_bash_4_2 ; then
 		maj=4 min=2
+	elif ___eapi_bash_5_0 ; then
+		maj=5 min=0
 	else
 		return
 	fi
@@ -184,9 +186,9 @@ export SANDBOX_ON=0
 # Ensure that $PWD is sane whenever possible, to protect against
 # exploitation of insecure search path for python -c in ebuilds.
 # See bug #239560, bug #469338, and bug #595028.
-if [[ -d ${HOME} ]]; then
-	# Use portage's temporary HOME directory if available.
-	cd "${HOME}" || die
+# EAPI 8 requires us to use an empty directory here.
+if [[ -d ${PORTAGE_BUILDDIR}/empty ]]; then
+	cd "${PORTAGE_BUILDDIR}/empty" || die
 else
 	cd "${PORTAGE_PYM_PATH}" || \
 		die "PORTAGE_PYM_PATH does not exist: '${PORTAGE_PYM_PATH}'"
@@ -241,6 +243,14 @@ inherit() {
 	ECLASS_DEPTH=$(($ECLASS_DEPTH + 1))
 	if [[ ${ECLASS_DEPTH} -gt 1 ]]; then
 		debug-print "*** Multiple Inheritence (Level: ${ECLASS_DEPTH})"
+
+		# Since ECLASS_DEPTH > 1, the following variables are locals from the
+		# previous inherit call in the call stack.
+		if [[ -n ${ECLASS} && -n ${!__export_funcs_var} ]] ; then
+			eqawarn "QA Notice: EXPORT_FUNCTIONS is called before inherit in ${ECLASS}.eclass."
+			eqawarn "For compatibility with PMS and to avoid breakage with Pkgcore, only call"
+			eqawarn "EXPORT_FUNCTIONS after inherit(s). Portage behavior may change in future."
+		fi
 	fi
 
 	local -x ECLASS
@@ -254,8 +264,10 @@ inherit() {
 	local B_DEPEND
 	local B_RDEPEND
 	local B_PDEPEND
-	local B_HDEPEND
 	local B_BDEPEND
+	local B_IDEPEND
+	local B_PROPERTIES
+	local B_RESTRICT
 	while [ "$1" ]; do
 		location=""
 		potential_location=""
@@ -300,16 +312,24 @@ inherit() {
 
 			# Retain the old data and restore it later.
 			unset B_IUSE B_REQUIRED_USE B_DEPEND B_RDEPEND B_PDEPEND
-			unset B_HDEPEND B_BDEPEND
+			unset B_BDEPEND B_IDEPEND B_PROPERTIES B_RESTRICT
 			[ "${IUSE+set}"       = set ] && B_IUSE="${IUSE}"
 			[ "${REQUIRED_USE+set}" = set ] && B_REQUIRED_USE="${REQUIRED_USE}"
 			[ "${DEPEND+set}"     = set ] && B_DEPEND="${DEPEND}"
 			[ "${RDEPEND+set}"    = set ] && B_RDEPEND="${RDEPEND}"
 			[ "${PDEPEND+set}"    = set ] && B_PDEPEND="${PDEPEND}"
-			[ "${HDEPEND+set}"    = set ] && B_HDEPEND="${HDEPEND}"
 			[ "${BDEPEND+set}"    = set ] && B_BDEPEND="${BDEPEND}"
-			unset IUSE REQUIRED_USE DEPEND RDEPEND PDEPEND HDEPEND
-			unset BDEPEND
+			unset IUSE REQUIRED_USE DEPEND RDEPEND PDEPEND BDEPEND IDEPEND
+
+			if ___eapi_has_accumulated_PROPERTIES; then
+				[[ ${PROPERTIES+set} == set ]] && B_PROPERTIES=${PROPERTIES}
+				unset PROPERTIES
+			fi
+			if ___eapi_has_accumulated_RESTRICT; then
+				[[ ${RESTRICT+set} == set ]] && B_RESTRICT=${RESTRICT}
+				unset RESTRICT
+			fi
+
 			#turn on glob expansion
 			set +f
 		fi
@@ -327,8 +347,8 @@ inherit() {
 			[ "${DEPEND+set}"       = set ] && E_DEPEND+="${E_DEPEND:+ }${DEPEND}"
 			[ "${RDEPEND+set}"      = set ] && E_RDEPEND+="${E_RDEPEND:+ }${RDEPEND}"
 			[ "${PDEPEND+set}"      = set ] && E_PDEPEND+="${E_PDEPEND:+ }${PDEPEND}"
-			[ "${HDEPEND+set}"      = set ] && E_HDEPEND+="${E_HDEPEND:+ }${HDEPEND}"
 			[ "${BDEPEND+set}"      = set ] && E_BDEPEND+="${E_BDEPEND:+ }${BDEPEND}"
+			[ "${IDEPEND+set}"      = set ] && E_IDEPEND+="${E_IDEPEND:+ }${IDEPEND}"
 
 			[ "${B_IUSE+set}"     = set ] && IUSE="${B_IUSE}"
 			[ "${B_IUSE+set}"     = set ] || unset IUSE
@@ -345,12 +365,29 @@ inherit() {
 			[ "${B_PDEPEND+set}"  = set ] && PDEPEND="${B_PDEPEND}"
 			[ "${B_PDEPEND+set}"  = set ] || unset PDEPEND
 
-			[ "${B_HDEPEND+set}"  = set ] && HDEPEND="${B_HDEPEND}"
-			[ "${B_HDEPEND+set}"  = set ] || unset HDEPEND
-
 			[ "${B_BDEPEND+set}"  = set ] && BDEPEND="${B_BDEPEND}"
 			[ "${B_BDEPEND+set}"  = set ] || unset BDEPEND
 
+			[ "${B_IDEPEND+set}"  = set ] && IDEPEND="${B_IDEPEND}"
+			[ "${B_IDEPEND+set}"  = set ] || unset IDEPEND
+
+			if ___eapi_has_accumulated_PROPERTIES; then
+				[[ ${PROPERTIES+set} == set ]] &&
+					E_PROPERTIES+=${E_PROPERTIES:+ }${PROPERTIES}
+				[[ ${B_PROPERTIES+set} == set ]] &&
+					PROPERTIES=${B_PROPERTIES}
+				[[ ${B_PROPERTIES+set} == set ]] ||
+					unset PROPERTIES
+			fi
+			if ___eapi_has_accumulated_RESTRICT; then
+				[[ ${RESTRICT+set} == set ]] &&
+					E_RESTRICT+=${E_RESTRICT:+ }${RESTRICT}
+				[[ ${B_RESTRICT+set} == set ]] &&
+					RESTRICT=${B_RESTRICT}
+				[[ ${B_RESTRICT+set} == set ]] ||
+					unset RESTRICT
+			fi
+
 			#turn on glob expansion
 			set +f
 
@@ -607,10 +644,10 @@ if ! has "$EBUILD_PHASE" clean cleanrm ; then
 		# In order to ensure correct interaction between ebuilds and
 		# eclasses, they need to be unset before this process of
 		# interaction begins.
-		unset EAPI DEPEND RDEPEND PDEPEND HDEPEND BDEPEND
+		unset EAPI DEPEND RDEPEND PDEPEND BDEPEND PROPERTIES RESTRICT
 		unset INHERITED IUSE REQUIRED_USE ECLASS E_IUSE E_REQUIRED_USE
-		unset E_DEPEND E_RDEPEND E_PDEPEND E_HDEPEND E_BDEPEND
-		unset PROVIDES_EXCLUDE REQUIRES_EXCLUDE
+		unset E_DEPEND E_RDEPEND E_PDEPEND E_BDEPEND E_IDEPEND E_PROPERTIES
+		unset E_RESTRICT PROVIDES_EXCLUDE REQUIRES_EXCLUDE
 
 		if [[ $PORTAGE_DEBUG != 1 || ${-/x/} != $- ]] ; then
 			source "$EBUILD" || die "error sourcing ebuild"
@@ -624,12 +661,6 @@ if ! has "$EBUILD_PHASE" clean cleanrm ; then
 			shopt -u failglob
 		fi
 
-		if [[ "${EBUILD_PHASE}" != "depend" ]] ; then
-			RESTRICT=${PORTAGE_RESTRICT}
-			[[ -e $PORTAGE_BUILDDIR/.ebuild_changed ]] && \
-			rm "$PORTAGE_BUILDDIR/.ebuild_changed"
-		fi
-
 		[ "${EAPI+set}" = set ] || EAPI=0
 
 		# export EAPI for helpers (especially since we unset it above)
@@ -645,12 +676,25 @@ if ! has "$EBUILD_PHASE" clean cleanrm ; then
 		DEPEND+="${DEPEND:+ }${E_DEPEND}"
 		RDEPEND+="${RDEPEND:+ }${E_RDEPEND}"
 		PDEPEND+="${PDEPEND:+ }${E_PDEPEND}"
-		HDEPEND+="${HDEPEND:+ }${E_HDEPEND}"
 		BDEPEND+="${BDEPEND:+ }${E_BDEPEND}"
 		REQUIRED_USE+="${REQUIRED_USE:+ }${E_REQUIRED_USE}"
-		
+
+		if ___eapi_has_accumulated_PROPERTIES; then
+			PROPERTIES+=${PROPERTIES:+ }${E_PROPERTIES}
+		fi
+		if ___eapi_has_accumulated_RESTRICT; then
+			RESTRICT+=${RESTRICT:+ }${E_RESTRICT}
+		fi
+
 		unset ECLASS E_IUSE E_REQUIRED_USE E_DEPEND E_RDEPEND E_PDEPEND
-		unset E_HDEPEND E_BDEPEND __INHERITED_QA_CACHE
+		unset E_BDEPEND E_PROPERTIES E_RESTRICT __INHERITED_QA_CACHE
+
+		if [[ "${EBUILD_PHASE}" != "depend" ]] ; then
+			PROPERTIES=${PORTAGE_PROPERTIES}
+			RESTRICT=${PORTAGE_RESTRICT}
+			[[ -e $PORTAGE_BUILDDIR/.ebuild_changed ]] && \
+			rm "$PORTAGE_BUILDDIR/.ebuild_changed"
+		fi
 
 		# alphabetically ordered by $EBUILD_PHASE value
 		case ${EAPI} in
@@ -701,7 +745,7 @@ if ! has "$EBUILD_PHASE" clean cleanrm ; then
 	fi
 fi
 
-if has nostrip ${FEATURES} ${RESTRICT} || has strip ${RESTRICT}
+if has nostrip ${FEATURES} ${PORTAGE_RESTRICT} || has strip ${PORTAGE_RESTRICT}
 then
 	export DEBUGBUILD=1
 fi
@@ -720,15 +764,15 @@ if [[ $EBUILD_PHASE = depend ]] ; then
 
 	auxdbkeys="DEPEND RDEPEND SLOT SRC_URI RESTRICT HOMEPAGE LICENSE
 		DESCRIPTION KEYWORDS INHERITED IUSE REQUIRED_USE PDEPEND BDEPEND
-		EAPI PROPERTIES DEFINED_PHASES HDEPEND UNUSED_04
+		EAPI PROPERTIES DEFINED_PHASES IDEPEND UNUSED_04
 		UNUSED_03 UNUSED_02 UNUSED_01"
 
-	if ! ___eapi_has_HDEPEND; then
-		unset HDEPEND
-	fi
 	if ! ___eapi_has_BDEPEND; then
 		unset BDEPEND
 	fi
+	if ! ___eapi_has_IDEPEND; then
+		unset IDEPEND
+	fi
 
 	# The extra $(echo) commands remove newlines.
 	if [ -n "${dbkey}" ] ; then
