@@ -187,6 +187,7 @@ def insert_optional_args(args):
 		'q' : y_or_n,
 		'v' : y_or_n,
 		'w' : y_or_n,
+		'W' : y_or_n,
 	}
 
 	arg_stack = args[:]
@@ -470,6 +471,7 @@ def parse_opts(tmpcmdline, silent=False):
 		},
 
 		"--deselect": {
+			"shortopt" : "-W",
 			"help"    : "remove atoms/sets from the world file",
 			"choices" : true_y_or_n
 		},
@@ -645,6 +647,11 @@ def parse_opts(tmpcmdline, silent=False):
 			"choices": y_or_n
 		},
 
+		"--quickpkg-direct-root": {
+			"help": "Specify the root to use as the --quickpkg-direct package source",
+			"action" : "store"
+		},
+
 		"--quiet": {
 			"shortopt" : "-q",
 			"help"     : "reduced or condensed output",
@@ -827,7 +834,7 @@ def parse_opts(tmpcmdline, silent=False):
 
 	tmpcmdline = insert_optional_args(tmpcmdline)
 
-	myoptions = parser.parse_args(args=tmpcmdline)
+	myoptions = getattr(parser, "parse_intermixed_args", parser.parse_args)(args=tmpcmdline)
 
 	if myoptions.alert in true_y:
 		myoptions.alert = True
@@ -1065,7 +1072,7 @@ def parse_opts(tmpcmdline, silent=False):
 
 		myoptions.deep = deep
 
-	if myoptions.jobs:
+	if myoptions.jobs is not None:
 		jobs = None
 		if myoptions.jobs == "True":
 			jobs = True
