@@ -1,4 +1,4 @@
-# Copyright 2018 Gentoo Foundation
+# Copyright 2018-2021 Gentoo Authors
 # Distributed under the terms of the GNU General Public License v2
 
 from portage import os
@@ -7,10 +7,6 @@ from portage.repository.storage.interface import (
 	RepoStorageInterface,
 )
 from portage.util.futures import asyncio
-from portage.util.futures.compat_coroutine import (
-	coroutine,
-	coroutine_return,
-)
 
 from _emerge.SpawnProcess import SpawnProcess
 
@@ -38,60 +34,55 @@ class HardlinkQuarantineRepoStorage(RepoStorageInterface):
 		self._spawn_kwargs = spawn_kwargs
 		self._current_update = None
 
-	@coroutine
-	def _check_call(self, cmd, loop=None):
+	async def _check_call(self, cmd):
 		"""
 		Run cmd and raise RepoStorageException on failure.
 
 		@param cmd: command to executre
 		@type cmd: list
 		"""
-		p = SpawnProcess(args=cmd, scheduler=asyncio._wrap_loop(loop), **self._spawn_kwargs)
+		p = SpawnProcess(args=cmd, scheduler=asyncio.get_event_loop(), **self._spawn_kwargs)
 		p.start()
-		if (yield p.async_wait()) != os.EX_OK:
+		if await p.async_wait() != os.EX_OK:
 			raise RepoStorageException('command exited with status {}: {}'.\
 				format(p.returncode, ' '.join(cmd)))
 
-	@coroutine
-	def init_update(self, loop=None):
+	async def init_update(self):
 		update_location = os.path.join(self._user_location, '.tmp-unverified-download-quarantine')
-		yield self._check_call(['rm', '-rf', update_location], loop=loop)
+		await self._check_call(['rm', '-rf', update_location])
 
 		# Use  rsync --link-dest to hardlink a files into self._update_location,
 		# since cp -l is not portable.
-		yield self._check_call(['rsync', '-a', '--link-dest', self._user_location,
+		await self._check_call(['rsync', '-a', '--link-dest', self._user_location,
 			'--exclude=/distfiles', '--exclude=/local', '--exclude=/lost+found', '--exclude=/packages',
 			'--exclude', '/{}'.format(os.path.basename(update_location)),
-			self._user_location + '/', update_location + '/'], loop=loop)
+			self._user_location + '/', update_location + '/'])
 
 		self._update_location = update_location
 
-		coroutine_return(self._update_location)
+		return self._update_location
 
 	@property
-	def current_update(self, loop=None):
+	def current_update(self):
 		if self._update_location is None:
 			raise RepoStorageException('current update does not exist')
 		return self._update_location
 
-	@coroutine
-	def commit_update(self, loop=None):
+	async def commit_update(self):
 		update_location = self.current_update
 		self._update_location = None
-		yield self._check_call(['rsync', '-a', '--delete',
+		await self._check_call(['rsync', '-a', '--delete',
 			'--exclude=/distfiles', '--exclude=/local', '--exclude=/lost+found', '--exclude=/packages',
 			'--exclude', '/{}'.format(os.path.basename(update_location)),
-			update_location + '/', self._user_location + '/'], loop=loop)
+			update_location + '/', self._user_location + '/'])
 
-		yield self._check_call(['rm', '-rf', update_location], loop=loop)
+		await self._check_call(['rm', '-rf', update_location])
 
-	@coroutine
-	def abort_update(self, loop=None):
+	async def abort_update(self):
 		if self._update_location is not None:
 			update_location = self._update_location
 			self._update_location = None
-			yield self._check_call(['rm', '-rf', update_location], loop=loop)
+			await self._check_call(['rm', '-rf', update_location])
 
-	@coroutine
-	def garbage_collection(self, loop=None):
-		yield self.abort_update(loop=loop)
+	async def garbage_collection(self):
+		await self.abort_update()
